@@ -1,3 +1,5 @@
+/*jslint browser: true */
+
 //
 // this is part of VDR Admin
 //
@@ -7,12 +9,16 @@ function open_help(url) {
 
 function del(message, suffix) {
 	check=confirm(message);
-	if(check) window.location.href=suffix;
+	if(check) {
+		window.location.href=suffix;
+	}
 }
 
 function change(message, suffix) {
 	check=confirm(message);
-	if(check) window.location.href=suffix;
+	if(check) {
+		window.location.href=suffix;
+	}
 }
 
 function mdel(but, message) {
@@ -26,18 +32,19 @@ function callurl( url ) {
 }
 
 function popup(URL, win_w, win_h) {
-	window.open(URL, '_new', 'width=' + win_w + ', height=' + win_h + ', scrollbars=yes, resizable=yes, toolbar=no, status=no');
+	window.open(URL, '_blank', 'width=' + win_w + ', height=' + win_h + ', scrollbars=yes, resizable=yes, toolbar=no, status=no');
 }
 
 function toolbar(URL) {
-	window.open(URL, '_new', 'width=200, height=50');
+	window.open(URL, '_blank', 'width=200, height=50');
 }
 
 function AllMessages(myform)
 {
 	for (var x = 0; x < myform.elements.length; x++) {
 		var y = myform.elements[x];
-		if (y.name != 'SELALL')
-				y.checked = myform.SELALL.checked;
+		if (y.name != 'SELALL') {
+			y.checked = myform.SELALL.checked;
+		}
 	}
 }
